Range-v3: range/v3/algorithm/set_algorithm.hpp File Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Classes | Namespaces
set_algorithm.hpp File Reference

## Classes
struct | ranges::v3::includes_fn
struct | ranges::v3::set_difference_fn
struct | ranges::v3::set_intersection_fn
struct | ranges::v3::set_symmetric_difference_fn
struct | ranges::v3::set_union_fn

## Namespaces
| ranges::v3
| Protect a callable so that it can be safely used in a bind expression without accidentally becoming a "nested" bind.